#ifndef WiFiWebserver_h
#define WiFiWebserver_h

#include <Arduino.h>

#include <WiFi.h>
#include <Param.h>


// define class functions and variables
class WiFiWebserver
{
    // which are accessible by main program
    public:

		// constructor (function name = class name)
		WiFiWebserver();
		
		
		void Start();

		//  Call this function regularly to look for client requests
		//  template see https://github.com/espressif/arduino-esp32/blob/master/libraries/WiFi/examples/SimpleWiFiServer/SimpleWiFiServer.ino
		//  returns empty string if no request from any client
		//  returns GET Parameter: everything after the "/?" if ADDRESS/?xxxx was entered by the user in the webbrowser
		//  returns "-" if ADDRESS but no GET Parameter was entered by the user in the webbrowser
		//  remark: client connection stays open after return
		String GetRequestGETParameter();

		String WebRequestHostAddress;     // public variable used to store Server IP-Address of HTTP-Request
		String WebRequestHostPage;        // public variable used to store the page URL of HTTP-Request


		// decodes Url-Escape-Codes in String
		String DecodeURLChars(String strURL);

		// extract key values from GET Parameter Expression
                // name1=Value1&name2=value2&name3=value3 and so on
                // pls note: no check of the name/keys !
		Param DeSerializeFromGETParameter(String GETParameter, Param ResultParam);

		// make a HTML table from a Param Key Value Set
                // for each Value in the Param:
                // first table column will be filled with Name/Key
                // second table column will be filled with a control to set the Value
		String SerializeToHTMLInputTable(Param TableParam);

		// Build a HTML page with a form 
                // InnerHTML is the code of the form with the HTML controls (textboxes, sliders and so on)
                // returns the HTML code of the page
		String FormHTML(String TitleOfForm, String InnerHTML);

		// Send HTML page to client, as HTTP response
		// client connection must be open (call Webserver_GetRequestGETParameter() first)
		void SendHTMLPage(String HTMLPage);


};

#endif